/****************************************************************************
** Meta object code from reading C++ file 'networkfetchextension.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../src/avogadro-1.2.0/libavogadro/src/extensions/networkfetchextension.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'networkfetchextension.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_Avogadro__NetworkFetchExtension[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: signature, parameters, type, tag, flags
      42,   33,   32,   32, 0x0a,
      65,   32,   32,   32, 0x08,
     124,  100,   95,   32, 0x08,

       0        // eod
};

static const char qt_meta_stringdata_Avogadro__NetworkFetchExtension[] = {
    "Avogadro::NetworkFetchExtension\0\0"
    "molecule\0setMolecule(Molecule*)\0"
    "replyFinished(QNetworkReply*)\0QUrl\0"
    "possibleRedirect,oldURL\0"
    "checkRedirect(QUrl,QUrl)\0"
};

void Avogadro::NetworkFetchExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        NetworkFetchExtension *_t = static_cast<NetworkFetchExtension *>(_o);
        switch (_id) {
        case 0: _t->setMolecule((*reinterpret_cast< Molecule*(*)>(_a[1]))); break;
        case 1: _t->replyFinished((*reinterpret_cast< QNetworkReply*(*)>(_a[1]))); break;
        case 2: { QUrl _r = _t->checkRedirect((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< QUrl*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObjectExtraData Avogadro::NetworkFetchExtension::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Avogadro::NetworkFetchExtension::staticMetaObject = {
    { &Extension::staticMetaObject, qt_meta_stringdata_Avogadro__NetworkFetchExtension,
      qt_meta_data_Avogadro__NetworkFetchExtension, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Avogadro::NetworkFetchExtension::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Avogadro::NetworkFetchExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Avogadro::NetworkFetchExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Avogadro__NetworkFetchExtension))
        return static_cast<void*>(const_cast< NetworkFetchExtension*>(this));
    return Extension::qt_metacast(_clname);
}

int Avogadro::NetworkFetchExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Extension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
static const uint qt_meta_data_Avogadro__NetworkFetchExtensionFactory[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

static const char qt_meta_stringdata_Avogadro__NetworkFetchExtensionFactory[] = {
    "Avogadro::NetworkFetchExtensionFactory\0"
};

void Avogadro::NetworkFetchExtensionFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObjectExtraData Avogadro::NetworkFetchExtensionFactory::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject Avogadro::NetworkFetchExtensionFactory::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Avogadro__NetworkFetchExtensionFactory,
      qt_meta_data_Avogadro__NetworkFetchExtensionFactory, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &Avogadro::NetworkFetchExtensionFactory::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *Avogadro::NetworkFetchExtensionFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *Avogadro::NetworkFetchExtensionFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_Avogadro__NetworkFetchExtensionFactory))
        return static_cast<void*>(const_cast< NetworkFetchExtensionFactory*>(this));
    if (!strcmp(_clname, "PluginFactory"))
        return static_cast< PluginFactory*>(const_cast< NetworkFetchExtensionFactory*>(this));
    if (!strcmp(_clname, "net.sourceforge.avogadro.pluginfactory/1.5"))
        return static_cast< Avogadro::PluginFactory*>(const_cast< NetworkFetchExtensionFactory*>(this));
    return QObject::qt_metacast(_clname);
}

int Avogadro::NetworkFetchExtensionFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    return _id;
}
QT_END_MOC_NAMESPACE
